@@ -3,7 +3,7 @@
 #' Estimate or extract degrees of freedom of models.
 #'
 #' @param model A statistical model.
-#' @param method Can be \code{"analytical"} (default, DoFs are estimated based on the model type), \code{"fit"}, in which case they are directly taken from the model if available (for Bayesian models, the goal (looking for help to make it happen) would be to refit the model as a frequentist one before extracting the DoFs), or \code{"any"}, which tries to extract DoF by any of those methods, whichever succeeds.
+#' @param method Can be \code{"analytical"} (default, DoFs are estimated based on the model type), \code{"fit"}, in which case they are directly taken from the model if available (for Bayesian models, the goal (looking for help to make it happen) would be to refit the model as a frequentist one before extracting the DoFs), \code{"ml1"} (see \code{\link{dof_ml1}}), \code{"satterthwaite"} (see \code{\link{dof_satterthwaite}}), \code{"kenward"} (see \code{\link{dof_kenward}}) or \code{"any"}, which tries to extract DoF by any of those methods, whichever succeeds.
 #'
 #' @examples
 #' model <- lm(Sepal.Length ~ Petal.Length * Species, data = iris)
@@ -13,7 +13,7 @@
 #' dof(model)
 #'
 #' library(lme4)
-#' model <- lmer(Sepal.Length ~ Petal.Length + (1|Species), data = iris)
+#' model <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
 #' dof(model)
 #' \donttest{
 #' library(rstanarm)
@@ -23,22 +23,34 @@
 #'   chains = 2,
 #'   refresh = 0
 #' )
-#' dof(model)}
+#' dof(model)
+#' }
 #' @export
 degrees_of_freedom <- function(model, method = "analytical") {
+  method <- match.arg(method, c("analytical", "any", "fit", "ml1", "satterthwaite", "kenward", "nokr", "wald"))
 
-  method <- match.arg(method, c("analytical", "any", "fit", "nokr"))
+  if (!.dof_method_ok(model, method)) {
+    method <- "any"
+  }
 
   if (method == "any") {
     dof <- .degrees_of_freedom_fit(model, verbose = FALSE)
     if (is.null(dof) || is.infinite(dof) || anyNA(dof)) {
       dof <- .degrees_of_freedom_analytical(model, kenward = FALSE)
     }
+  } else if (method == "ml1") {
+    dof <- dof_ml1(model)
+  } else if (method == "wald") {
+    dof <- Inf
+  } else if (method == "satterthwaite") {
+    dof <- dof_satterthwaite(model)
+  } else if (method == "kenward") {
+    dof <- dof_kenward(model)
   } else if (method == "analytical") {
     dof <- .degrees_of_freedom_analytical(model)
   } else if (method == "nokr") {
     dof <- .degrees_of_freedom_analytical(model, kenward = FALSE)
-  } else{
+  } else {
     dof <- .degrees_of_freedom_fit(model)
   }
 
@@ -63,8 +75,8 @@ dof <- degrees_of_freedom
   n <- insight::n_obs(model)
 
   if (isTRUE(kenward) && inherits(model, "lmerMod")) {
-    dof <- as.numeric(t(dof_kenward(model)))
-  } else{
+    dof <- as.numeric(dof_kenward(model))
+  } else {
     dof <- rep(n - nparam, nparam)
   }
 
@@ -75,14 +87,14 @@ dof <- degrees_of_freedom
 
 
 
+#' @importFrom bayestestR bayesian_as_frequentist
 #' @importFrom stats df.residual
 #' @keywords internal
 .degrees_of_freedom_fit <- function(model, verbose = TRUE) {
   info <- insight::model_info(model)
 
   if (info$is_bayesian) {
-    # model <- bayestestR::refit_as_frequentist(model)
-    stop("Method 'fit' is not yet available.")
+    model <- bayestestR::bayesian_as_frequentist(model)
   }
 
   # 1st try
@@ -103,3 +115,14 @@ dof <- degrees_of_freedom
 
   dof
 }
+
+
+
+
+.dof_method_ok <- function(model, method) {
+  if (!insight::model_info(model)$is_linear && method %in% c("satterthwaite", "kenward")) {
+    warning(sprintf("'%s'-degrees of freedoms are only available for linear mixed models.", method), call. = FALSE)
+    return(FALSE)
+  }
+  return(TRUE)
+}
