@@ -5,6 +5,8 @@ dof_kenward <- function(model) {
     stop("Package `pbkrtest` required for Kenward-Rogers approximation.", call. = FALSE)
   }
 
+  parameters <- find_parameters(model, effects = "fixed", flatten = TRUE)
+
   L <- as.data.frame(diag(rep(1, n_parameters(model, effects = "fixed"))))
-  sapply(L, pbkrtest::get_ddf_Lb, object = model)
+  stats::setNames(sapply(L, pbkrtest::get_ddf_Lb, object = model), parameters)
 }
