@@ -30,10 +30,11 @@ model_parameters.stanreg <- function(model, centrality = "median", dispersion =
   # Processing
   parameters <- .extract_parameters_bayesian(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = bf_prior, diagnostic = diagnostic, priors = priors, iterations = iterations, effects = effects, ...)
 
-  if (effects == "fixed")
+  if (effects == "fixed") {
     attr(parameters, "pretty_names") <- format_parameters(model)
-  else
+  } else {
     parameters <- .add_pretty_names(parameters, model, effects = effects, component = NULL)
+  }
 
   attr(parameters, "ci") <- ci
   attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
@@ -43,6 +44,28 @@ model_parameters.stanreg <- function(model, centrality = "median", dispersion =
 }
 
 
+#' @export
+model_parameters.stanmvreg <- function(model, centrality = "median", dispersion = FALSE, ci = .89, ci_method = "hdi", test = "pd", rope_range = "default", rope_ci = 1.0, bf_prior = NULL, diagnostic = c("ESS", "Rhat"), priors = TRUE, iterations = 1000, effects = "fixed", ...) {
+
+  # Processing
+  parameters <- .extract_parameters_bayesian(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = bf_prior, diagnostic = diagnostic, priors = priors, iterations = iterations, effects = effects, ...)
+  parameters$Parameter <- gsub("^(.*)\\|(.*)", "\\2", parameters$Parameter)
+
+  if (effects == "fixed") {
+    attr(parameters, "pretty_names") <- format_parameters(model)
+  } else {
+    parameters <- .add_pretty_names(parameters, model, effects = effects, component = NULL)
+  }
+
+  attr(parameters, "ci") <- ci
+  attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  class(parameters) <- c("parameters_model", "see_parameters_model", class(parameters))
+
+  parameters
+}
+
+
+
 #' @rdname model_parameters.stanreg
 #' @inheritParams insight::get_parameters
 #' @export
@@ -51,10 +74,11 @@ model_parameters.brmsfit <- function(model, centrality = "median", dispersion =
   # Processing
   parameters <- .extract_parameters_bayesian(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = bf_prior, diagnostic = diagnostic, priors = priors, iterations = iterations, effects = effects, component = component, ...)
 
-  if (effects == "fixed" && component == "conditional")
+  if (effects == "fixed" && component == "conditional") {
     attr(parameters, "pretty_names") <- format_parameters(model)
-  else
+  } else {
     parameters <- .add_pretty_names(parameters, model, effects = effects, component = component)
+  }
 
   attr(parameters, "ci") <- ci
   attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
@@ -77,3 +101,18 @@ model_parameters.MCMCglmm <- function(model, centrality = "median", dispersion =
 
   parameters
 }
+
+
+
+#' @export
+model_parameters.mcmc <- function(model, centrality = "median", dispersion = FALSE, ci = .89, ci_method = "hdi", test = c("pd", "rope"), rope_range = "default", rope_ci = 1.0, iterations = 1000, ...) {
+
+  # Processing
+  parameters <- .extract_parameters_bayesian(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = NULL, diagnostic = NULL, priors = FALSE, iterations = iterations, ...)
+
+  attr(parameters, "ci") <- ci
+  attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  class(parameters) <- c("parameters_model", "see_parameters_model", class(parameters))
+
+  parameters
+}
